@@ -1,24 +1,29 @@
 #' Retrieve immediate children taxa for a given taxon name or ID.
 #'
-#' This function is different from \code{\link{downstream}} in that it only collects immediate
-#' taxonomic children, while \code{\link{downstream}} collects taxonomic names down to a specified
-#' taxonomic rank, e.g., getting all species in a family.
+#' This function is different from \code{\link{downstream}} in that it only
+#' collects immediate taxonomic children, while \code{\link{downstream}}
+#' collects taxonomic names down to a specified taxonomic rank, e.g.,
+#' getting all species in a family.
 #'
 #' @export
-#' @param x Vector of taxa names (character) or IDs (character or numeric) to query.
-#' @param db character; database to query. One or more of \code{itis}, \code{col}, or \code{ncbi}.
-#' Note that each taxonomic data source has their own identifiers, so that if you
-#' provide the wrong \code{db} value for the identifier you could get a result,
-#' but it will likely be wrong (not what you were expecting).
-#' @param rows (numeric) Any number from 1 to infinity. If the default NA, all rows are
-#' considered. Note that this parameter is ignored if you pass in a taxonomic id of any of the
-#' acceptable classes: tsn, colid. NCBI has a method for this function but rows doesn't work.
+#' @param x Vector of taxa names (character) or IDs (character or numeric)
+#' to query.
+#' @param db character; database to query. One or more of \code{itis},
+#' \code{col}, \code{ncbi}, or \code{worms}. Note that each taxonomic data
+#' source has their own identifiers, so that if you provide the wrong
+#' \code{db} value for the identifier you could get a result, but it will
+#' likely be wrong (not what you were expecting).
+#' @param rows (numeric) Any number from 1 to infinity. If the default NA, all
+#' rows are considered. Note that this parameter is ignored if you pass in a
+#' taxonomic id of any of the acceptable classes: tsn, colid. NCBI has a
+#' method for this function but rows doesn't work.
 #' @param ... Further args passed on to \code{\link{col_children}},
-#' \code{\link{gethierarchydownfromtsn}}, or \code{\link{ncbi_children}}.
+#' \code{\link[ritis]{hierarchy_down}}, \code{\link{ncbi_children}},
+#' or \code{\link[worrms]{wm_children}}
 #' See those functions for what parameters can be passed on.
 #'
-#' @return A named list of data.frames with the children names of every supplied taxa.
-#' You get an NA if there was no match in the database.
+#' @return A named list of data.frames with the children names of every
+#' supplied taxa. You get an NA if there was no match in the database.
 #'
 #' @examples \dontrun{
 #' # Plug in taxonomic IDs
@@ -32,12 +37,17 @@
 #' children("Salmo", db = 'col')
 #' children("Salmo", db = 'itis')
 #' children("Salmo", db = 'ncbi')
+#' children("Salmo", db = 'worms')
 #'
 #' # Plug in IDs
 #' (id <- get_colid("Apis"))
 #' children(id)
 #'
-#' ## Equivalently, plug in the call to get the id via e.g., get_colid into children
+#' (id <- get_wormsid("Platanista"))
+#' children(id)
+#'
+#' ## Equivalently, plug in the call to get the id via e.g., get_colid
+#' ## into children
 #' (id <- get_colid("Apis"))
 #' children(id)
 #' children(get_colid("Apis"))
@@ -70,30 +80,37 @@ children <- function(...){
 
 #' @export
 #' @rdname children
-children.default <- function(x, db = NULL, rows = NA, ...) {
+children.default <- function(x, db = NULL, rows = NaN, ...) {
   nstop(db)
-  switch(db,
-         itis = {
-           id <- process_children_ids(x, db, get_tsn, rows = rows, ...)
-           setNames(children(id, ...), x)
-         },
+  switch(
+    db,
+    itis = {
+      id <- process_children_ids(x, db, get_tsn, rows = rows, ...)
+      stats::setNames(children(id, ...), x)
+    },
 
-         col = {
-           id <- process_children_ids(x, db, get_colid, rows = rows, ...)
-           setNames(children(id, ...), x)
-         },
+    col = {
+      id <- process_children_ids(x, db, get_colid, rows = rows, ...)
+      stats::setNames(children(id, ...), x)
+    },
 
-         ncbi = {
-           if (all(grepl("^[[:digit:]]*$", x))) {
-             id <- x
-             class(id) <- "uid"
-             setNames(children(id, ...), x)
-           } else {
-             out <- ncbi_children(name = x, ...)
-             structure(out, class = 'children', db = 'ncbi', .Names = x)
-           }
-         },
-         stop("the provided db value was not recognised", call. = FALSE)
+    ncbi = {
+      if (all(grepl("^[[:digit:]]*$", x))) {
+        id <- x
+        class(id) <- "uid"
+        stats::setNames(children(id, ...), x)
+      } else {
+        out <- ncbi_children(name = x, ...)
+        structure(out, class = 'children', db = 'ncbi', .Names = x)
+      }
+    },
+
+    worms = {
+      id <- process_children_ids(x, db, get_wormsid, rows = rows, ...)
+      stats::setNames(children(id, ...), x)
+    },
+
+    stop("the provided db value was not recognised", call. = FALSE)
   )
 }
 
@@ -109,13 +126,13 @@ process_children_ids <- function(input, db, fxn, ...){
 
 #' @export
 #' @rdname children
-children.tsn <- function(x,  db = NULL, ...) {
+children.tsn <- function(x, db = NULL, ...) {
   fun <- function(y){
     # return NA if NA is supplied
     if (is.na(y)) {
       out <- NA
     } else {
-		  out <- gethierarchydownfromtsn(tsn = y, ...)
+		  out <- ritis::hierarchy_down(y, ...)
     }
   }
   out <- lapply(x, fun)
@@ -146,6 +163,46 @@ children.colid <- function(x,  db = NULL, ...) {
   return(out)
 }
 
+df2dt2tbl <- function(x) {
+  tibble::as_tibble(
+    data.table::setDF(
+      data.table::rbindlist(
+        x, use.names = TRUE, fill = TRUE)
+    )
+  )
+}
+
+#' @export
+#' @rdname children
+children.wormsid <- function(x, db = NULL, ...) {
+  fun <- function(y){
+    # return NA if NA is supplied
+    if (is.na(y)) {
+      out <- NA
+    } else {
+      out <- worrms::wm_children(as.numeric(y))
+      out <- list(out)
+      i <- 1
+      while (NROW(out[[length(out)]]) == 50) {
+        i <- i + 1
+        out[[i]] <- worrms::wm_children(
+          as.numeric(y),
+          offset = sum(unlist(sapply(out, NROW))))
+      }
+      out <- df2dt2tbl(out)
+      stats::setNames(
+        out[names(out) %in% c('AphiaID', 'scientificname', 'rank')],
+        c('childtaxa_id', 'childtaxa_name', 'childtaxa_rank')
+      )
+    }
+  }
+  out <- lapply(x, fun)
+  names(out) <- x
+  class(out) <- 'children'
+  attr(out, 'db') <- 'worms'
+  return(out)
+}
+
 #' @export
 #' @rdname children
 children.ids <- function(x, db = NULL, ...) {
