@@ -2,28 +2,30 @@
 #'
 #' @export
 #' @param scinames character; One or more scientific names or partial names.
-#' @param db character; Data source, one of \emph{"eol"} (default), \emph{"itis"}
-#'   or \emph{"ncbi"}. Note that each taxonomic data source has their own identifiers,
-#'   so that if you provide the wrong \code{db} value for the identifier you could get
-#'   a result, but it will likely be wrong (not what you were expecting).
-#' @param simplify (logical) If TRUE, simplify output to a vector of names. If FALSE,
-#'    return variable formats from different sources, usually a data.frame. Only applies to
-#'    eol and itis.
-#' @param ... Further arguments passed on to functions \code{\link[taxize]{get_uid}},
-#'    \code{\link[taxize]{get_tsn}}.
-#' @param id character; identifiers, as returned by \code{\link[taxize]{get_tsn}},
-#'    \code{\link[taxize]{get_uid}}.
+#' @param db character; Data source, one of \emph{"eol"} (default),
+#' \emph{"itis"} \emph{"ncbi"}, \emph{"worms"}. Note that each taxonomic data
+#' source has their own identifiers,  so that if you provide the wrong
+#' \code{db} value for the identifier you could get a result, but it will
+#' likely be wrong (not what you were expecting).
+#' @param simplify (logical) If TRUE, simplify output to a vector of names.
+#' If FALSE, return variable formats from different sources, usually a
+#' data.frame. Only applies to eol and itis.
+#' @param ... Further arguments passed on to functions
+#' \code{\link[taxize]{get_uid}}, \code{\link[taxize]{get_tsn}}.
+#' @param id character; identifiers, as returned by
+#' \code{\link[taxize]{get_tsn}}, \code{\link[taxize]{get_uid}}.
 #'
-#' @details Note that EOL requires an API key. You can pass in your EOL api key in the function
-#' call like \code{sci2comm('Helianthus annuus', key="<your eol api key>")}. You can also store your
-#' EOL API key in your .Rprofile file as \code{options(eolApiKey = "<your eol api key>")}, or
-#' just for the current session by running \code{options(eolApiKey = "<your eol api key>")} in
+#' @details Note that EOL requires an API key. You can pass in your EOL api
+#' key in the function call like
+#' \code{sci2comm('Helianthus annuus', key="<your eol api key>")}. You can
+#' also store your EOL API key in your .Rprofile file as
+#' \code{options(eolApiKey = "<your eol api key>")}, or just for the current
+#' session by running \code{options(eolApiKey = "<your eol api key>")} in
 #' the console.
 #'
-#' @return List of character vectors.
+#' @return List of character vectors, named by input taxon name, or taxon ID
 #'
-#' @seealso \code{\link[ritis]{search_common}}, \code{\link[taxize]{eol_search}},
-#' \code{\link[taxize]{tp_search}}, \code{\link[taxize]{comm2sci}}
+#' @seealso \code{\link[taxize]{comm2sci}}
 #'
 #' @author Scott Chamberlain (myrmecocystus@@gmail.com)
 #'
@@ -32,10 +34,13 @@
 #' sci2comm(scinames='Helianthus annuus', db='itis')
 #' sci2comm(scinames=c('Helianthus annuus', 'Poa annua'))
 #' sci2comm(scinames='Puma concolor', db='ncbi')
+#' sci2comm('Gadus morhua', db='worms')
+#' sci2comm('Pomatomus saltatrix', db='worms')
 #'
 #' # Passing id in, works for sources: itis and ncbi, not eol
 #' sci2comm(get_tsn('Helianthus annuus'))
 #' sci2comm(get_uid('Helianthus annuus'))
+#' sci2comm(get_wormsid('Gadus morhua'))
 #'
 #' # Don't simplify returned
 #' sci2comm(get_tsn('Helianthus annuus'), simplify=FALSE)
@@ -63,7 +68,8 @@ sci2comm.default <- function(scinames, db='eol', simplify=TRUE, ...) {
   eol2comm <- function(x, ...){
     tmp <- eol_search(terms = x, ...)
     pageids <- tmp[grep(x, tmp$name), "pageid"]
-    dfs <- tc(lapply(pageids, function(x) eol_pages(taxonconceptID = x, common_names = TRUE, ...)$vernac))
+    dfs <- tc(lapply(pageids, function(x)
+      eol_pages(taxonconceptID = x, common_names = TRUE, ...)$vernac))
     tt <- ldply(dfs[sapply(dfs, class) == "data.frame"])
     if (simplify) {
       ss <- as.character(tt$vernacularname)
@@ -78,18 +84,25 @@ sci2comm.default <- function(scinames, db='eol', simplify=TRUE, ...) {
     ncbi_foo(uid, ...)
   }
 
+  worms2comm <- function(x, ...){
+    id <- get_wormsid(x, ...)
+    worms_foo(id, ...)
+  }
+
   getsci <- function(nn, simplify, ...){
-    switch(db,
-           eol = eol2comm(nn, simplify, ...),
-           itis = itis2comm(nn, simplify, ...),
-           ncbi = ncbi2comm(nn, ...))
+    switch(
+      db,
+      eol = eol2comm(nn, simplify, ...),
+      itis = itis2comm(nn, simplify, ...),
+      ncbi = ncbi2comm(nn, ...),
+      worms = worms2comm(nn, ...)
+    )
   }
   temp <- lapply(scinames, getsci, simplify, ...)
   names(temp) <- scinames
   temp
 }
 
-#' @method sci2comm uid
 #' @export
 #' @rdname sci2comm
 sci2comm.uid <- function(id, ...) {
@@ -98,7 +111,6 @@ sci2comm.uid <- function(id, ...) {
   return(out)
 }
 
-#' @method sci2comm tsn
 #' @export
 #' @rdname sci2comm
 sci2comm.tsn <- function(id, simplify=TRUE, ...) {
@@ -107,6 +119,14 @@ sci2comm.tsn <- function(id, simplify=TRUE, ...) {
   return(out)
 }
 
+#' @export
+#' @rdname sci2comm
+sci2comm.wormsid <- function(id, simplify=TRUE, ...) {
+  out <- lapply(id, function(x) worms_foo(x, simplify, ...))
+  names(out) <- id
+  return(out)
+}
+
 itis_foo <- function(x, simplify=TRUE, ...){
   # if tsn is not found
   if (is.na(x)) {
@@ -134,8 +154,27 @@ ncbi_foo <- function(x, ...){
   res <- con_utf8(tt)
   ttp <- xml2::read_xml(res)
   # common name
-  out <- xml_text(xml_find_all(ttp, "//TaxaSet/Taxon/OtherNames/GenbankCommonName"))
+  out <- xml_text(xml_find_all(ttp,
+                               "//TaxaSet/Taxon/OtherNames/GenbankCommonName"))
   # NCBI limits requests to three per second
   Sys.sleep(0.33)
   return(out)
 }
+
+worms_foo <- function(x, simplify=TRUE, ...){
+  # if id is not found
+  if (is.na(x)) {
+    out <- NA
+  } else {
+    out <- worrms::wm_common_id(as.numeric(x))
+    #if common name is not found
+    if (nrow(out) == 0) {
+      out <- NA
+    }
+  }
+  if (simplify) {
+    if (!inherits(out, "tbl_df")) out else as.character(out$vernacular)
+  } else{
+    out
+  }
+}
