@@ -168,3 +168,20 @@ move_col <- function(tt, y){
 }
 
 move_col2 <- function(x, y) x[ c(names(x)[-grep(y, names(x))], y) ]
+
+move_col_begin <- function(tt, y){
+  tt[ c(y, names(tt)[ -sapply(y, function(m) grep(m, names(tt))) ]) ]
+}
+
+pop <- function(x, nms) {
+  x[ !names(x) %in% nms ]
+}
+
+assert <- function(x, y) {
+  if (!is.null(x)) {
+    if (!class(x) %in% y) {
+      stop(deparse(substitute(x)), " must be of class ",
+           paste0(y, collapse = ", "), call. = FALSE)
+    }
+  }
+}
